@@ -26,6 +26,11 @@ program
       process.exit()
     }
 
+    if (!options.collection) {
+      console.log(`The --filename parameter is required`.red);
+      process.exit()
+    }
+
     console.log('Trying to import data.. Please wait..');
 
     options.api = program.api
@@ -43,8 +48,37 @@ program
     })
   })
 
-/*if (!process.argv.slice(3).length) {
-  program.outputHelp();
-}*/
+program
+  .command('export')
+  .description('Export items')
+  //.option('-l, --limit [limit]', 'Amount of items you want to load')
+  //.option('-f, --filename [filename]', 'JSON file')
+  .action(function(options){
+    if (!program.api) {
+      console.log(`The --api parameter is required`.red);
+      process.exit()
+    }
+
+    if (!program.collection) {
+      console.log(`The --collection parameter is required`.red);
+      process.exit()
+    }
+
+    options.api = program.api
+    options.collection = program.collection
+
+    service.export(options)
+    .then(function(val) {
+      console.log(JSON.stringify(val, null, 2));
+    })
+    .catch(function(err) {
+      console.log(err)
+      console.log('Unexpected error..'.red)
+    })
+  })
+
+if (process.argv.length < 3) {
+  program.outputHelp()
+}
 
 program.parse(process.argv);
